#!/usr/bin/gnuplot

set colors classic

set xl "diameter {/Helvetica-Oblique D} / km"
set yl "number of asteroids {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset +0.0

set xr [0.8*100.e-9:1000]
y1=0.8
y2=1.e26
set yr [y1:y2]
set logscale xy
set xtics 10
set mytics 10
set ytics 10
set mytics 10
set xtics format "10^{%T}"
set ytics format "10^{%T}"
set tics front
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.3 font "Helvetica,14"

set arrow from 1.0,graph 0 rto 0,graph 1 lt 0
set arrow from 0.001,graph 0 rto 0,graph 1 lt 0
set arrow from 100.e-9,graph 0 rto 0,graph 1 lt 0

p \
  "../../dat/Bottke_etal_2015.dat" u (10.**$1):(10.**$2) w p pt 7 lc '#ffffff' not,\
  "../../dat/Bottke_etal_2015.dat" u (10.**$1):(10.**$2) w p pt 7 lc 'gray' t "{/=14 Bottke etal. (2015)}",\
  "../../dat/Harris_etal_2015.dat" u (10.**$1):(10.**$2) w p pt 7 lc 'gray' t "{/=14 Harris et al. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p pt 7 lc '#ffffff' not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p pt 7 lc 'gray' not,\
  "../src/MB_2018.dat_hc"            w l lc 'gray' t "observed MB",\
  "../src/490_Veritas_family.dat_hc" w l lc 'gray' t "observed Veritas",\
  "../src/832_Karin_family.dat_hc"   w l lc 'gray' t "observed Karin",\
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/4000.out | ./hc.awk" u 1:2 w l lc '#0066ff' t "evolved MB",\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../*[0-9]*/tmp/4000.out | ./hc.awk" u 1:2 w l lc 'gray'    t "evolved NEO",\
  "<awk '(FNR==1){ print \"\"; } ($2==3)' ../*[0-9]*/tmp/4000.out | ./hc.awk" u 1:2 w l lc '#000099' t "evolved Veritas",\
  "<awk '(FNR==1){ print \"\"; } ($2==4)' ../*[0-9]*/tmp/4000.out | ./hc.awk" u 1:2 w l lc '#ffaaff' t "evolved Karin",\
  "<echo 100.e-9 1.2e25" w p pt 1 ps 3 lw 3 lc '#0066ff' t "zodiacal cloud",\
  "<echo 100.e-9 2.7e24" w p pt 1 ps 3 lw 3 lc '#0000cc' t "IRAS 8{/Symbol\260} band",\
  "<echo 100.e-9 1.3e24" w p pt 1 ps 3 lw 3 lc '#cc00ff' t "IRAS 2.1{/Symbol\260} band"

pa -1

set term postscript eps enh color solid "Helvetica" 18
set out "sfd_39_MB_none.eps"
set size 0.65,0.9
set lmargin 7.5
set rmargin 2.1
set bmargin 3.0
set tmargin 0.8
rep

system("eps2png sfd_39_MB_none.eps")

q

  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l lc 'gray' t "initial MB"    ,\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l lc 'gray' t "initial NEO",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l lc 'gray' t "initial Veritas",\
  "<./hc_sfd.awk ../src/sfd2.dat_EDITED" u 1:2 w l lc 'gray' t "initial Karin",\

